@@ -19,6 +19,8 @@
 #  DEALINGS IN THE SOFTWARE.
 """Base Command Module."""
 
+from __future__ import annotations
+
 import abc
 import collections
 import contextlib
@@ -26,18 +28,27 @@ import logging
 import os
 import shutil
 import subprocess
-from collections.abc import Callable
-from typing import Any
+
+from typing import TYPE_CHECKING, Any
 
 import click
 import wcmatch.pathlib
 import wcmatch.wcmatch
+
 from click_help_colors import HelpColorsCommand, HelpColorsGroup
 from wcmatch import glob
 
 import molecule.scenarios
+
 from molecule import config, logger, text, util
 from molecule.console import should_do_markup
+from molecule.scenario import Scenario
+
+
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+    from molecule.scenario import Scenario
 
 LOG = logging.getLogger(__name__)
 MOLECULE_GLOB = os.environ.get("MOLECULE_GLOB", "molecule/*/molecule.yml")
@@ -50,8 +61,11 @@ class Base(metaclass=abc.ABCMeta):
     def __init__(self, c: config.Config) -> None:
         """Initialize code for all command classes.
 
-        :param c: An instance of a Molecule config.
-        :returns: None
+        Args:
+            c: An instance of a Molecule config.
+
+        Returns:
+            None
         """
         self._config = c
         self._setup()
@@ -60,23 +74,32 @@ class Base(metaclass=abc.ABCMeta):
         """Decorate execute from all subclasses."""
         super().__init_subclass__()
         for wrapper in logger.get_section_loggers():
-            cls.execute = wrapper(cls.execute)  # type: ignore
+            cls.execute = wrapper(cls.execute)  # type: ignore  # noqa: PGH003
 
     @abc.abstractmethod
-    def execute(self, action_args=None):  # pragma: no cover
-        pass
+    def execute(
+        self: Base,
+        action_args: list[str] | None = None,
+    ) -> None:  # pragma: no cover
+        """Abstract method to execute the command.
+
+        Args:
+            action_args: An optional list of arguments to pass to the action.
+        """
 
     def _setup(self) -> None:
-        """Prepare Molecule's provisioner and returns None.
-
-        :return: None
-        """
+        """Prepare Molecule's provisioner and returns None."""
         self._config.write()
         self._config.provisioner.write_config()
         self._config.provisioner.manage_inventory()
 
 
-def execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args=()):
+def execute_cmdline_scenarios(
+    scenario_name: str | None,
+    args: dict[str, Any],
+    command_args: dict[str, Any],
+    ansible_args: tuple[()] | tuple[str] = (),
+) -> None:
     """Execute scenario sequences based on parsed command-line arguments.
 
     This is useful for subcommands that run scenario sequences, which
@@ -85,18 +108,17 @@ def execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args=()
     ``args`` and ``command_args`` are combined using :func:`get_configs`
     to generate the scenario(s) configuration.
 
-    :param scenario_name: Name of scenario to run, or ``None`` to run all.
-    :param args: ``args`` dict from ``click`` command context
-    :param command_args: dict of command arguments, including the target
-                         subcommand to execute
-    :returns: None
-
+    Args:
+        scenario_name: Name of scenario to run, or ``None`` to run all.
+        args: ``args`` dict from ``click`` command context
+        command_args: dict of command arguments, including the target
+        ansible_args: Optional tuple of arguments to pass to the `ansible-playbook` command
     """
     glob_str = MOLECULE_GLOB
     if scenario_name:
         glob_str = glob_str.replace("*", scenario_name)
     scenarios = molecule.scenarios.Scenarios(
-        get_configs(args, command_args, ansible_args, glob_str),
+        get_configs(args, command_args, ansible_args, glob_str),  # type: ignore[no-untyped-call]
         scenario_name,
     )
 
@@ -136,47 +158,52 @@ def execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args=()
                 # always prune ephemeral dir if destroying on failure
                 scenario.prune()
                 if scenario.config.is_parallel:
-                    scenario._remove_scenario_state_directory()
+                    scenario._remove_scenario_state_directory()  # noqa: SLF001
                 util.sysexit()
             else:
                 raise
 
 
-def execute_subcommand(config, subcommand_and_args):
-    """Execute subcommand."""
+def execute_subcommand(
+    current_config: config.Config,
+    subcommand_and_args: str,
+) -> Any:  # noqa: ANN401
+    """Execute subcommand.
+
+    Args:
+        current_config: An instance of a Molecule config.
+        subcommand_and_args: A string representing the subcommand and arguments.
+    """
     (subcommand, *args) = subcommand_and_args.split(" ")
     command_module = getattr(molecule.command, subcommand)
-    command = getattr(command_module, text.camelize(subcommand))
+    command = getattr(command_module, text.camelize(subcommand))  # type: ignore[no-untyped-call]
 
     # knowledge of the current action is used by some provisioners
     # to ensure they behave correctly during certain sequence steps,
     # particularly the setting of ansible options in create/destroy,
     # and is also used for reporting in execute_cmdline_scenarios
-    config.action = subcommand
+    current_config.action = subcommand
 
-    return command(config).execute(args)
+    return command(current_config).execute(args)
 
 
-def execute_scenario(scenario):
+def execute_scenario(scenario: Scenario) -> None:
     """Execute each command in the given scenario's configured sequence.
 
-    :param scenario: The scenario to execute.
-    :returns: None
+    Args:
+        scenario: The scenario to execute.
     """
     for action in scenario.sequence:
         execute_subcommand(scenario.config, action)
 
-    if (
-        "destroy" in scenario.sequence
-        and scenario.config.command_args.get("destroy") != "never"
-    ):
+    if "destroy" in scenario.sequence and scenario.config.command_args.get("destroy") != "never":
         scenario.prune()
 
         if scenario.config.is_parallel:
-            scenario._remove_scenario_state_directory()
+            scenario._remove_scenario_state_directory()  # noqa: SLF001
 
 
-def filter_ignored_scenarios(scenario_paths) -> list[str]:
+def filter_ignored_scenarios(scenario_paths) -> list[str]:  # type: ignore[no-untyped-def]  # noqa: ANN001, D103
     command = ["git", "check-ignore", *scenario_paths]
 
     with contextlib.suppress(subprocess.CalledProcessError, FileNotFoundError):
@@ -190,37 +217,36 @@ def filter_ignored_scenarios(scenario_paths) -> list[str]:
 
     try:
         ignored = proc.stdout.splitlines()
-        paths = [
-            candidate for candidate in scenario_paths if str(candidate) not in ignored
-        ]
+        paths = [candidate for candidate in scenario_paths if str(candidate) not in ignored]
     except NameError:
         paths = scenario_paths
 
     return paths
 
 
-def get_configs(args, command_args, ansible_args=(), glob_str=MOLECULE_GLOB):
-    """Glob the current directory for Molecule config files, instantiate config \
-    objects, and returns a list.
+def get_configs(args, command_args, ansible_args=(), glob_str=MOLECULE_GLOB):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
+    """Glob the current directory for Molecule config files.
 
-    :param args: A dict of options, arguments and commands from the CLI.
-    :param command_args: A dict of options passed to the subcommand from
-     the CLI.
-    :param ansible_args: An optional tuple of arguments provided to the
-     `ansible-playbook` command.
-    :return: list
+    Instantiate config objects, and returns a list.
+
+    Args:
+        args: A dict of options, arguments and commands from the CLI.
+        command_args: A dict of options passed to the subcommand from the CLI.
+        ansible_args: An optional tuple of arguments provided to the `ansible-playbook` command.
+        glob_str: A string representing the glob used to find Molecule config files.
+
+    Returns:
+        A list of Config objects.
     """
     scenario_paths = glob.glob(
         glob_str,
-        flags=wcmatch.pathlib.GLOBSTAR
-        | wcmatch.pathlib.BRACE
-        | wcmatch.pathlib.DOTGLOB,
+        flags=wcmatch.pathlib.GLOBSTAR | wcmatch.pathlib.BRACE | wcmatch.pathlib.DOTGLOB,
     )
 
     scenario_paths = filter_ignored_scenarios(scenario_paths)
     configs = [
         config.Config(
-            molecule_file=util.abs_path(c),
+            molecule_file=util.abs_path(c),  # type: ignore[arg-type]
             args=args,
             command_args=command_args,
             ansible_args=ansible_args,
@@ -232,11 +258,12 @@ def get_configs(args, command_args, ansible_args=(), glob_str=MOLECULE_GLOB):
     return configs
 
 
-def _verify_configs(configs, glob_str=MOLECULE_GLOB):
+def _verify_configs(configs: list[config.Config], glob_str: str = MOLECULE_GLOB) -> None:
     """Verify a Molecule config was found and returns None.
 
-    :param configs: A list containing absolute paths to Molecule config files.
-    :return: None
+    Args:
+        configs: A list containing absolute paths to Molecule config files.
+        glob_str: A string representing the glob used to find Molecule config files.
     """
     if configs:
         scenario_names = [c.scenario.name for c in configs]
@@ -250,11 +277,19 @@ def _verify_configs(configs, glob_str=MOLECULE_GLOB):
         util.sysexit_with_message(msg)
 
 
-def _get_subcommand(string):
+def _get_subcommand(string: str) -> str:
+    """Return the subcommand from a string.
+
+    Args:
+        string: A string containing a subcommand.
+
+    Returns:
+        A string representing the subcommand.
+    """
     return string.split(".")[-1]
 
 
-def click_group_ex():
+def click_group_ex():  # type: ignore[no-untyped-def]  # noqa: ANN201
     """Return extended version of click.group()."""
     # Color coding used to group command types, documented only here as we may
     # decide to change them later.
@@ -283,14 +318,14 @@ def click_group_ex():
 
 def click_command_ex() -> Callable[[Callable[..., Any]], click.Command]:
     """Return extended version of click.command()."""
-    return click.command(  # type: ignore
+    return click.command(
         cls=HelpColorsCommand,
         help_headers_color="yellow",
         help_options_color="green",
     )
 
 
-def result_callback(*args, **kwargs):
+def result_callback(*args, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN002, ANN003, ANN201, ARG001
     """Click natural exit callback."""
     # We want to be used we run out custom exit code, regardless if run was
     # a success or failure.
