@@ -27,6 +27,7 @@ import click
 from molecule import util
 from molecule.command import base
 
+
 LOG = logging.getLogger(__name__)
 MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
 
@@ -34,12 +35,8 @@ MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
 class Check(base.Base):
     """Check Command Class."""
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to perform a `molecule check` and \
-        returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
+        """Execute the actions necessary to perform a `molecule check` and returns None."""
         self._config.provisioner.check()
 
 
@@ -56,15 +53,13 @@ class Check(base.Base):
     default=MOLECULE_PARALLEL,
     help="Enable or disable parallel mode. Default is disabled.",
 )
-def check(ctx, scenario_name, parallel):  # pragma: no cover
-    """Use the provisioner to perform a Dry-Run (destroy, dependency, create, \
-    prepare, converge).
-    """
+def check(ctx, scenario_name, parallel):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
+    """Use the provisioner to perform a Dry-Run (destroy, dependency, create, prepare, converge)."""
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {"parallel": parallel, "subcommand": subcommand}
 
     if parallel:
-        util.validate_parallel_cmd_args(command_args)
+        util.validate_parallel_cmd_args(command_args)  # type: ignore[no-untyped-call]
 
     base.execute_cmdline_scenarios(scenario_name, args, command_args)
