@@ -25,18 +25,15 @@ import click
 
 from molecule.command import base
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Cleanup(base.Base):
     """Cleanup Command Class."""
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to cleanup the instances and returns \
-        None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
+        """Execute the actions necessary to cleanup the instances and returns None."""
         if not self._config.provisioner.playbooks.cleanup:
             msg = "Skipping, cleanup playbook not configured."
             LOG.warning(msg)
@@ -53,12 +50,13 @@ class Cleanup(base.Base):
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
     help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
-def cleanup(ctx, scenario_name="default"):  # pragma: no cover
-    """Use the provisioner to cleanup any changes made to external systems during \
-    the stages of testing.
+def cleanup(ctx, scenario_name="default"):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
+    """Use the provisioner to cleanup any changes.
+
+    Any changes made to external systems during the stages of testing.
     """
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {"subcommand": subcommand}
 
     base.execute_cmdline_scenarios(scenario_name, args, command_args)
