@@ -29,6 +29,7 @@ from molecule.api import drivers
 from molecule.command import base
 from molecule.config import DEFAULT_DRIVER
 
+
 LOG = logging.getLogger(__name__)
 MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
 
@@ -36,12 +37,8 @@ MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
 class Destroy(base.Base):
     """Destroy Command Class."""
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to perform a `molecule destroy` and \
-        returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
+        """Execute the actions necessary to perform a `molecule destroy` and returns None."""
         if self._config.command_args.get("destroy") == "never":
             msg = "Skipping, '--destroy=never' requested."
             LOG.warning(msg)
@@ -76,10 +73,10 @@ class Destroy(base.Base):
     default=False,
     help="Enable or disable parallel mode. Default is disabled.",
 )
-def destroy(ctx, scenario_name, driver_name, __all, parallel):  # pragma: no cover
+def destroy(ctx, scenario_name, driver_name, __all, parallel):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
     """Use the provisioner to destroy the instances."""
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {
         "parallel": parallel,
         "subcommand": subcommand,
@@ -90,6 +87,6 @@ def destroy(ctx, scenario_name, driver_name, __all, parallel):  # pragma: no cov
         scenario_name = None
 
     if parallel:
-        util.validate_parallel_cmd_args(command_args)
+        util.validate_parallel_cmd_args(command_args)  # type: ignore[no-untyped-call]
 
     base.execute_cmdline_scenarios(scenario_name, args, command_args)
