@@ -31,18 +31,18 @@ from molecule.command import base as command_base
 from molecule.command.init import base
 from molecule.config import DEFAULT_DRIVER, MOLECULE_EMBEDDED_DATA_DIR
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Scenario(base.Base):
-    """
-    Scenario Class.
+    """Scenario Class.
 
     .. program:: molecule init scenario bar --role-name foo
 
     .. option:: molecule init scenario bar --role-name foo
 
-        Initialize a new scenario. In order to customise the role, please refer
+        Initialize a new scenario. In order to customize the role, please refer
         to the `init role` command.
 
     .. program:: cd foo; molecule init scenario bar --role-name foo
@@ -62,24 +62,17 @@ class Scenario(base.Base):
         """Construct Scenario."""
         self._command_args = command_args
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to perform a `molecule init scenario` and \
-        returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
+        """Execute the actions necessary to perform a `molecule init scenario` and returns None."""
         scenario_name = self._command_args["scenario_name"]
 
         msg = f"Initializing new scenario {scenario_name}..."
         LOG.info(msg)
-        molecule_directory = config.molecule_directory(os.getcwd())
-        scenario_directory = os.path.join(molecule_directory, scenario_name)
+        molecule_directory = config.molecule_directory(os.getcwd())  # noqa: PTH109
+        scenario_directory = os.path.join(molecule_directory, scenario_name)  # noqa: PTH118
 
-        if os.path.isdir(scenario_directory):
-            msg = (
-                f"The directory molecule/{scenario_name} exists. "
-                "Cannot create new scenario."
-            )
+        if os.path.isdir(scenario_directory):  # noqa: PTH112
+            msg = f"The directory molecule/{scenario_name} exists. Cannot create new scenario."
             util.sysexit_with_message(msg)
 
         extra_vars = json.dumps(self._command_args)
@@ -103,14 +96,14 @@ class Scenario(base.Base):
         LOG.info(msg)
 
 
-def _role_exists(ctx, param, value: str):  # pragma: no cover
+def _role_exists(ctx, param, value: str):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN202, ARG001
     # if role name was not mentioned we assume that current directory is the
     # one hosting the role and determining the role name.
     if not value:
-        value = os.path.basename(os.getcwd())
+        value = os.path.basename(os.getcwd())  # noqa: PTH109, PTH119
 
-    role_directory = os.path.join(os.pardir, value)
-    if not os.path.exists(role_directory):
+    role_directory = os.path.join(os.pardir, value)  # noqa: PTH118
+    if not os.path.exists(role_directory):  # noqa: PTH110
         msg = f"The role '{value}' not found. Please choose the proper role name."
         util.sysexit_with_message(msg)
     return value
@@ -142,12 +135,12 @@ def _role_exists(ctx, param, value: str):  # pragma: no cover
     default=command_base.MOLECULE_DEFAULT_SCENARIO_NAME,
     required=False,
 )
-def scenario(
-    ctx,
-    dependency_name,
-    driver_name,
-    provisioner_name,
-    scenario_name,
+def scenario(  # type: ignore[no-untyped-def]  # noqa: ANN201
+    ctx,  # noqa: ANN001, ARG001
+    dependency_name,  # noqa: ANN001
+    driver_name,  # noqa: ANN001
+    provisioner_name,  # noqa: ANN001
+    scenario_name,  # noqa: ANN001
 ):  # pragma: no cover
     """Initialize a new scenario for use with Molecule.
 
@@ -162,4 +155,4 @@ def scenario(
     }
 
     s = Scenario(command_args)
-    s.execute()
+    s.execute()  # type: ignore[no-untyped-call]
