@@ -23,6 +23,7 @@
 import logging
 
 import click
+
 from rich import box
 from rich.syntax import Syntax
 from rich.table import Table
@@ -32,18 +33,15 @@ from molecule.command import base
 from molecule.console import console
 from molecule.status import Status
 
+
 LOG = logging.getLogger(__name__)
 
 
 class List(base.Base):
     """List command shows information about current scenarios."""
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to perform a `molecule list` and \
-        returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
+        """Execute the actions necessary to perform a `molecule list` and returns None."""
         return self._config.driver.status()
 
 
@@ -57,15 +55,15 @@ class List(base.Base):
     default="simple",
     help="Change output format. (simple)",
 )
-def list(ctx, scenario_name, format):  # pragma: no cover
+def list(ctx, scenario_name, format):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201, A001, A002
     """List status of instances."""
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {"subcommand": subcommand, "format": format}
 
     statuses = []
     s = scenarios.Scenarios(
-        base.get_configs(args, command_args, glob_str="**/molecule/*/molecule.yml"),
+        base.get_configs(args, command_args, glob_str="**/molecule/*/molecule.yml"),  # type: ignore[no-untyped-call]
         scenario_name,
     )
     for scenario in s:
@@ -78,17 +76,18 @@ def list(ctx, scenario_name, format):  # pragma: no cover
         if format == "plain":
             headers = []
             table_format = format
-        _print_tabulate_data(headers, statuses, table_format)
+        _print_tabulate_data(headers, statuses, table_format)  # type: ignore[no-untyped-call]
     else:
-        _print_yaml_data(headers, statuses)
+        _print_yaml_data(headers, statuses)  # type: ignore[no-untyped-call]
 
 
-def _print_tabulate_data(headers, data, table_format):  # pragma: no cover
+def _print_tabulate_data(headers, data, table_format):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN202
     """Show the tabulate data on the screen and returns None.
 
-    :param headers: A list of column headers.
-    :param data:  A list of tabular data to display.
-    :returns: None
+    Args:
+        headers: A list of column headers.
+        data: A list of tabular data to display.
+        table_format: A string containing the table format.
     """
     if table_format == "plain":
         for line in data:
@@ -102,9 +101,9 @@ def _print_tabulate_data(headers, data, table_format):  # pragma: no cover
         console.print(t)
 
 
-def _print_yaml_data(headers, data):  # pragma: no cover
-    l = [
-        dict(zip(headers, [getattr(datum, field) for field in datum._fields]))
+def _print_yaml_data(headers, data):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN202
+    l = [  # noqa: E741
+        dict(zip(headers, [getattr(datum, field) for field in datum._fields], strict=False))
         for datum in data
     ]
 
