@@ -29,33 +29,30 @@ import click
 from molecule import scenarios, util
 from molecule.command import base
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Login(base.Base):
     """Login Command Class."""
 
-    def __init__(self, c) -> None:
+    def __init__(self, c) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
         """Construct Login."""
         super().__init__(c)
         self._pt = None
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to perform a `molecule login` and \
-        returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
+        """Execute the actions necessary to perform a `molecule login` and returns None."""
         c = self._config
         if (not c.state.created) and c.driver.managed:
             msg = "Instances not created.  Please create instances first."
             util.sysexit_with_message(msg)
 
         hosts = [d["name"] for d in self._config.platforms.instances]
-        hostname = self._get_hostname(hosts)
-        self._get_login(hostname)
+        hostname = self._get_hostname(hosts)  # type: ignore[no-untyped-call]
+        self._get_login(hostname)  # type: ignore[no-untyped-call]
 
-    def _get_hostname(self, hosts):
+    def _get_hostname(self, hosts):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
         hostname = self._config.command_args.get("host")
         host_list = "\n".join(sorted(hosts))
         if hostname is None:
@@ -90,7 +87,7 @@ class Login(base.Base):
 
         return match[0]
 
-    def _get_login(self, hostname):  # pragma: no cover
+    def _get_login(self, hostname):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN202
         # ruff: noqa: S605,S607
         lines, columns = os.popen("stty size", "r").read().split()
         login_options = self._config.driver.login_options(hostname)
@@ -98,7 +95,7 @@ class Login(base.Base):
         login_options["lines"] = lines
         if not self._config.driver.login_cmd_template:
             LOG.warning(
-                "Login command is not supported for [dim]%s[/] host because 'login_cmd_template' was not defined in driver options.",
+                "Login command is not supported for [dim]%s[/] host because 'login_cmd_template' was not defined in driver options.",  # noqa: E501
                 login_options["instance"],
             )
             return
@@ -118,12 +115,12 @@ class Login(base.Base):
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
     help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
-def login(ctx, host, scenario_name):  # pragma: no cover
+def login(ctx, host, scenario_name):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
     """Log in to one instance."""
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {"subcommand": subcommand, "host": host}
 
-    s = scenarios.Scenarios(base.get_configs(args, command_args), scenario_name)
+    s = scenarios.Scenarios(base.get_configs(args, command_args), scenario_name)  # type: ignore[no-untyped-call]
     for scenario in s.all:
         base.execute_subcommand(scenario.config, subcommand)
