@@ -27,12 +27,14 @@ from molecule.api import drivers
 from molecule.command import base
 from molecule.config import DEFAULT_DRIVER
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Prepare(base.Base):
-    """This action is for the purpose of preparing a molecule managed instance \
-    before the :py:class:`molecule.command.converge.Converge` action is run.
+    """This action is for the purpose of preparing a molecule managed instance.
+
+    Done before the :py:class:`molecule.command.converge.Converge` action is run.
 
     Tasks contained within the ``prepare.yml`` playbook in the scenario
     directory will be run remotely on the managed instance. This action is run
@@ -82,12 +84,8 @@ class Prepare(base.Base):
         molecule.yml.
     """
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to prepare the instances and returns \
-        None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
+        """Execute the actions necessary to prepare the instances and returns None."""
         if self._config.state.prepared and not self._config.command_args.get("force"):
             msg = "Skipping, instances already prepared."
             LOG.warning(msg)
@@ -99,7 +97,7 @@ class Prepare(base.Base):
             return
 
         self._config.provisioner.prepare()
-        self._config.state.change_state("prepared", True)
+        self._config.state.change_state("prepared", True)  # noqa: FBT003
 
 
 @base.click_command_ex()
@@ -122,10 +120,10 @@ class Prepare(base.Base):
     default=False,
     help="Enable or disable force mode. Default is disabled.",
 )
-def prepare(ctx, scenario_name, driver_name, force):  # pragma: no cover
+def prepare(ctx, scenario_name, driver_name, force):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
     """Use the provisioner to prepare the instances into a particular starting state."""
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {
         "subcommand": subcommand,
         "driver_name": driver_name,
