@@ -29,6 +29,7 @@ from molecule.api import drivers
 from molecule.command import base
 from molecule.config import DEFAULT_DRIVER
 
+
 LOG = logging.getLogger(__name__)
 MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
 MOLECULE_PLATFORM_NAME = os.environ.get("MOLECULE_PLATFORM_NAME", None)
@@ -37,12 +38,8 @@ MOLECULE_PLATFORM_NAME = os.environ.get("MOLECULE_PLATFORM_NAME", None)
 class Test(base.Base):
     """Test Command Class."""
 
-    def execute(self, action_args=None):
-        """Execute the actions necessary to perform a `molecule test` and \
-        returns None.
-
-        :return: None
-        """
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
+        """Execute the actions necessary to perform a `molecule test` and returns None."""
 
 
 @base.click_command_ex()
@@ -83,19 +80,19 @@ class Test(base.Base):
     help="Enable or disable parallel mode. Default is disabled.",
 )
 @click.argument("ansible_args", nargs=-1, type=click.UNPROCESSED)
-def test(
-    ctx,
-    scenario_name,
-    driver_name,
-    __all,
-    destroy,
-    parallel,
-    ansible_args,
-    platform_name,
+def test(  # type: ignore[no-untyped-def]  # noqa: ANN201, PLR0913
+    ctx,  # noqa: ANN001
+    scenario_name,  # noqa: ANN001
+    driver_name,  # noqa: ANN001
+    __all,  # noqa: ANN001
+    destroy,  # noqa: ANN001
+    parallel,  # noqa: ANN001
+    ansible_args,  # noqa: ANN001
+    platform_name,  # noqa: ANN001
 ):  # pragma: no cover
-    """Test (dependency, cleanup, destroy, syntax, create, prepare, converge, idempotence, side_effect, verify, cleanup, destroy)."""
+    """Test (dependency, cleanup, destroy, syntax, create, prepare, converge, idempotence, side_effect, verify, cleanup, destroy)."""  # noqa: E501
     args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args = {
         "parallel": parallel,
         "destroy": destroy,
@@ -108,6 +105,6 @@ def test(
         scenario_name = None
 
     if parallel:
-        util.validate_parallel_cmd_args(command_args)
+        util.validate_parallel_cmd_args(command_args)  # type: ignore[no-untyped-call]
 
     base.execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args)
