@@ -23,6 +23,7 @@ import copy
 import logging
 import os
 import warnings
+
 from collections.abc import MutableMapping
 from pathlib import Path
 from uuid import uuid4
@@ -38,6 +39,7 @@ from molecule.model import schema_v3
 from molecule.provisioner import ansible
 from molecule.util import boolean
 
+
 LOG = logging.getLogger(__name__)
 MOLECULE_DEBUG = boolean(os.environ.get("MOLECULE_DEBUG", "False"))
 MOLECULE_VERBOSITY = int(os.environ.get("MOLECULE_VERBOSITY", 0))
@@ -46,13 +48,13 @@ MOLECULE_FILE = "molecule.yml"
 MOLECULE_KEEP_STRING = "MOLECULE_"
 DEFAULT_DRIVER = "default"
 
-MOLECULE_EMBEDDED_DATA_DIR = os.path.dirname(data_module)
+MOLECULE_EMBEDDED_DATA_DIR = os.path.dirname(data_module)  # noqa: PTH120
 
 
 @cache
 def ansible_version() -> Version:
     """Retrieve Ansible version."""
-    warnings.warn(
+    warnings.warn(  # noqa: B028
         "molecule.config.ansible_version is deprecated, will be removed in the future.",
         category=DeprecationWarning,
     )
@@ -63,7 +65,7 @@ def ansible_version() -> Version:
 class NewInitCaller(type):
     """NewInitCaller."""
 
-    def __call__(cls, *args, **kwargs):
+    def __call__(cls, *args, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN002, ANN003, ANN204, D102
         obj = type.__call__(cls, *args, **kwargs)
         obj.after_init()
         return obj
@@ -87,24 +89,20 @@ class Config(metaclass=NewInitCaller):
 
     # pylint: disable=too-many-instance-attributes
     # Config objects should be allowed to have any number of attributes
-    def __init__(
+    def __init__(  # type: ignore[no-untyped-def]
         self,
-        molecule_file: str,
-        args={},
-        command_args={},
-        ansible_args=(),
+        molecule_file: str,  # pylint: disable=redefined-outer-name
+        args={},  # noqa: ANN001, B006
+        command_args={},  # noqa: ANN001, B006
+        ansible_args=(),  # noqa: ANN001
     ) -> None:
         """Initialize a new config class and returns None.
 
-        :param molecule_file: A string containing the path to the Molecule file
-         to be parsed.
-        :param args: An optional dict of options, arguments and commands from
-         the CLI.
-        :param command_args: An optional dict of options passed to the
-         subcommand from the CLI.
-        :param ansible_args: An optional tuple of arguments provided to the
-         ``ansible-playbook`` command.
-        :returns: None
+        Args:
+            molecule_file: A string containing the path to the Molecule file to be parsed.
+            args: An optional dict of options, arguments and commands from the CLI.
+            command_args: An optional dict of options passed to the subcommand from the CLI.
+            ansible_args: An optional tuple of arguments provided to the `ansible-playbook` command.
         """
         self.molecule_file = molecule_file
         self.args = args
@@ -113,20 +111,23 @@ class Config(metaclass=NewInitCaller):
         self.config = self._get_config()
         self._action = None
         self._run_uuid = str(uuid4())
-        self.project_directory = os.getenv("MOLECULE_PROJECT_DIRECTORY", os.getcwd())
+        self.project_directory = os.getenv(
+            "MOLECULE_PROJECT_DIRECTORY",
+            os.getcwd(),  # noqa: PTH109
+        )
         self.runtime = app.runtime
         self.scenario_path = Path(molecule_file).parent
 
-    def after_init(self):
-        self.config = self._reget_config()
+    def after_init(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        self.config = self._reget_config()  # type: ignore[no-untyped-call]
         if self.molecule_file:
-            self._validate()
+            self._validate()  # type: ignore[no-untyped-call]
 
-    def write(self) -> None:
+    def write(self) -> None:  # noqa: D102
         util.write_file(self.config_file, util.safe_dump(self.config))
 
     @property
-    def ansible_collections_path(self):
+    def ansible_collections_path(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Return collection path variable for current version of Ansible."""
         # https://github.com/ansible/ansible/pull/70007
         if self.runtime.version >= Version("2.10.0.dev0"):
@@ -134,47 +135,47 @@ class Config(metaclass=NewInitCaller):
         return "ANSIBLE_COLLECTIONS_PATHS"
 
     @property
-    def config_file(self):
-        return os.path.join(self.scenario.ephemeral_directory, MOLECULE_FILE)
+    def config_file(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        return os.path.join(self.scenario.ephemeral_directory, MOLECULE_FILE)  # noqa: PTH118
 
     @property
-    def is_parallel(self):
+    def is_parallel(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.command_args.get("parallel", False)
 
     @property
-    def platform_name(self):
+    def platform_name(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.command_args.get("platform_name", None)
 
     @property
-    def debug(self):
+    def debug(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.args.get("debug", MOLECULE_DEBUG)
 
     @property
-    def env_file(self):
+    def env_file(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return util.abs_path(self.args.get("env_file"))
 
     @property
-    def subcommand(self):
+    def subcommand(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.command_args["subcommand"]
 
     @property
-    def action(self):
+    def action(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._action
 
     @action.setter
-    def action(self, value):
+    def action(self, value):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
         self._action = value
 
     @property
-    def cache_directory(self):
+    def cache_directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return "molecule_parallel" if self.is_parallel else "molecule"
 
     @property
-    def molecule_directory(self):
+    def molecule_directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return molecule_directory(self.project_directory)
 
     @cached_property
-    def dependency(self):
+    def dependency(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         dependency_name = self.config["dependency"]["name"]
         if dependency_name == "galaxy":
             return ansible_galaxy.AnsibleGalaxy(self)
@@ -183,13 +184,14 @@ class Config(metaclass=NewInitCaller):
         return None
 
     @cached_property
-    def driver(self):
-        driver_name = self._get_driver_name()
+    def driver(self):  # type: ignore[no-untyped-def] # noqa: ANN201
+        """Return driver name."""
+        driver_name = self._get_driver_name()  # type: ignore[no-untyped-call]
         driver = None
 
         api_drivers = api.drivers(config=self)
         if driver_name not in api_drivers:
-            msg = f"Failed to find driver {driver_name}. Please ensure that the driver is correctly installed."
+            msg = f"Failed to find driver {driver_name}. Please ensure that the driver is correctly installed."  # noqa: E501
             util.sysexit_with_message(msg)
 
         driver = api_drivers[driver_name]
@@ -197,8 +199,8 @@ class Config(metaclass=NewInitCaller):
 
         return driver
 
-    @property  # type: ignore
-    def env(self):
+    @property
+    def env(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return {
             "MOLECULE_DEBUG": str(self.debug),
             "MOLECULE_FILE": self.config_file,
@@ -218,7 +220,7 @@ class Config(metaclass=NewInitCaller):
         }
 
     @cached_property
-    def platforms(self):
+    def platforms(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return platforms.Platforms(
             self,
             parallelize_platforms=self.is_parallel,
@@ -226,28 +228,28 @@ class Config(metaclass=NewInitCaller):
         )
 
     @cached_property
-    def provisioner(self):
+    def provisioner(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         provisioner_name = self.config["provisioner"]["name"]
         if provisioner_name == "ansible":
             return ansible.Ansible(self)
         return None
 
     @cached_property
-    def scenario(self):
+    def scenario(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return scenario.Scenario(self)
 
     @cached_property
-    def state(self):
-        myState = state.State(self)
+    def state(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        myState = state.State(self)  # noqa: N806
         # look at state file for molecule.yml date modified and warn if they do not match
-        if self.molecule_file and os.path.isfile(self.molecule_file):
-            modTime = os.path.getmtime(self.molecule_file)
+        if self.molecule_file and os.path.isfile(self.molecule_file):  # noqa: PTH113
+            modTime = os.path.getmtime(self.molecule_file)  # noqa: PTH204, N806
             if myState.molecule_yml_date_modified is None:
                 myState.change_state("molecule_yml_date_modified", modTime)
             elif myState.molecule_yml_date_modified != modTime:
                 LOG.warning(
-                    "The scenario config file ('%s') has been modified since the scenario was created. "
-                    "If recent changes are important, reset the scenario with 'molecule destroy' to clean up created items or "
+                    "The scenario config file ('%s') has been modified since the scenario was created. "  # noqa: E501
+                    "If recent changes are important, reset the scenario with 'molecule destroy' to clean up created items or "  # noqa: E501
                     "'molecule reset' to clear current configuration.",
                     self.molecule_file,
                 )
@@ -255,10 +257,10 @@ class Config(metaclass=NewInitCaller):
         return state.State(self)
 
     @cached_property
-    def verifier(self):
-        return api.verifiers(self).get(self.config["verifier"]["name"], None)
+    def verifier(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        return api.verifiers(self).get(self.config["verifier"]["name"], None)  # type: ignore[no-untyped-call]
 
-    def _get_driver_name(self):
+    def _get_driver_name(self):  # type: ignore[no-untyped-def] # noqa: ANN202
         # the state file contains the driver from the last run
         driver_from_state_file = self.state.driver
         # the user may supply a driver on the command line
@@ -272,6 +274,8 @@ class Config(metaclass=NewInitCaller):
             driver_name = driver_from_cli
         else:
             driver_name = driver_from_scenario
+        if driver_name is None:
+            driver_name = "default"
 
         if driver_from_cli and (driver_from_cli != driver_name):
             msg = (
@@ -291,36 +295,38 @@ class Config(metaclass=NewInitCaller):
             msg = (
                 f"Driver '{driver_name}' is currently in use but the scenario config "
                 f"has changed and now defines '{driver_from_scenario}'. "
-                "To change drivers, run 'molecule destroy' for converged scenarios or 'molecule reset' otherwise."
+                "To change drivers, run 'molecule destroy' for converged scenarios or 'molecule reset' otherwise."  # noqa: E501
             )
             LOG.warning(msg)
 
         return driver_name
 
-    def _get_config(self) -> MutableMapping:
+    def _get_config(self) -> MutableMapping:  # type: ignore[type-arg]
         """Perform a prioritized recursive merge of config files.
 
         Returns a new dict.  Prior to merging the config files are interpolated with
         environment variables.
 
-        :return: dict
+        Returns:
+            dict: The merged config.
         """
         return self._combine(keep_string=MOLECULE_KEEP_STRING)
 
-    def _reget_config(self):
+    def _reget_config(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
         """Perform the same prioritized recursive merge from `get_config`.
 
         Interpolates the ``keep_string`` left behind in the original
         ``get_config`` call.  This is probably __very__ bad.
 
-        :return: dict
+        Returns:
+            dict: The merged config.
         """
         env = util.merge_dicts(os.environ, self.env)
         env = set_env_from_file(env, self.env_file)
 
         return self._combine(env=env)
 
-    def _combine(self, env=os.environ, keep_string=None) -> MutableMapping:
+    def _combine(self, env=os.environ, keep_string=None) -> MutableMapping:  # type: ignore[no-untyped-def, type-arg]  # noqa: ANN001
         """Perform a prioritized recursive merge of config files.
 
         Returns a new dict.  Prior to merging the config files are interpolated with
@@ -331,12 +337,13 @@ class Config(metaclass=NewInitCaller):
         3. Loads the scenario's ``molecule file`` and merges on top of previous
            merge.
 
-        :return: dict
+        Returns:
+            dict: The merged config.
         """
         defaults = self._get_defaults()
         base_configs = filter(os.path.exists, self.args.get("base_config", []))
         for base_config in base_configs:
-            with open(base_config) as stream:
+            with open(base_config) as stream:  # noqa: PTH123
                 s = stream.read()
                 interpolated_config = self._interpolate(s, env, keep_string)
                 defaults = util.merge_dicts(
@@ -345,7 +352,7 @@ class Config(metaclass=NewInitCaller):
                 )
 
         if self.molecule_file:
-            with open(self.molecule_file) as stream:
+            with open(self.molecule_file) as stream:  # noqa: PTH123
                 s = stream.read()
                 interpolated_config = self._interpolate(s, env, keep_string)
                 defaults = util.merge_dicts(
@@ -355,7 +362,7 @@ class Config(metaclass=NewInitCaller):
 
         return defaults
 
-    def _interpolate(self, stream: str, env: MutableMapping, keep_string: str) -> str:
+    def _interpolate(self, stream: str, env: MutableMapping, keep_string: str) -> str:  # type: ignore[type-arg]
         env = set_env_from_file(env, self.env_file)
 
         i = interpolation.Interpolator(interpolation.TemplateWithDefaults, env)
@@ -363,18 +370,17 @@ class Config(metaclass=NewInitCaller):
         try:
             return i.interpolate(stream, keep_string)
         except interpolation.InvalidInterpolation as e:
-            msg = (
-                f"parsing config file '{self.molecule_file}'.\n\n{e.place}\n{e.string}"
-            )
+            msg = f"parsing config file '{self.molecule_file}'.\n\n{e.place}\n{e.string}"
             util.sysexit_with_message(msg)
         return ""
 
-    def _get_defaults(self) -> MutableMapping:
+    def _get_defaults(self) -> MutableMapping:  # type: ignore[type-arg]
         if not self.molecule_file:
             scenario_name = "default"
         else:
             scenario_name = (
-                os.path.basename(os.path.dirname(self.molecule_file)) or "default"
+                os.path.basename(os.path.dirname(self.molecule_file))  # noqa: PTH119, PTH120
+                or "default"
             )
         return {
             "dependency": {
@@ -461,11 +467,11 @@ class Config(metaclass=NewInitCaller):
             },
         }
 
-    def _validate(self):
+    def _validate(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
         msg = f"Validating schema {self.molecule_file}."
         LOG.debug(msg)
 
-        errors = schema_v3.validate(self.config)
+        errors = schema_v3.validate(self.config)  # type: ignore[no-untyped-call]
         if errors:
             msg = f"Failed to validate {self.molecule_file}\n\n{errors}"
             util.sysexit_with_message(msg)
@@ -473,17 +479,17 @@ class Config(metaclass=NewInitCaller):
 
 def molecule_directory(path: str) -> str:
     """Return directory of the current scenario."""
-    return os.path.join(path, MOLECULE_DIRECTORY)
+    return os.path.join(path, MOLECULE_DIRECTORY)  # noqa: PTH118
 
 
 def molecule_file(path: str) -> str:
     """Return file path of current scenario."""
-    return os.path.join(path, MOLECULE_FILE)
+    return os.path.join(path, MOLECULE_FILE)  # noqa: PTH118
 
 
-def set_env_from_file(env: MutableMapping[str, str], env_file: str) -> MutableMapping:
+def set_env_from_file(env: MutableMapping[str, str], env_file: str) -> MutableMapping:  # type: ignore[type-arg]
     """Load environment from file."""
-    if env_file and os.path.exists(env_file):
+    if env_file and os.path.exists(env_file):  # noqa: PTH110
         env = copy.copy(env)
         d = util.safe_load_file(env_file)
         for k, v in d.items():
