@@ -2,12 +2,14 @@
 
 import os
 import sys
+
 from typing import Any
 
 from enrich.console import Console
 from rich.style import Style
 from rich.theme import Theme
 
+
 theme = Theme(
     {
         "info": "dim cyan",
@@ -28,15 +30,13 @@ theme = Theme(
 
 
 # Based on Ansible implementation
-def to_bool(a: Any) -> bool:
+def to_bool(a: Any) -> bool:  # noqa: ANN401
     """Return a bool for the arg."""
     if a is None or isinstance(a, bool):
         return bool(a)
     if isinstance(a, str):
         a = a.lower()
-    if a in ("yes", "on", "1", "true", 1):
-        return True
-    return False
+    return a in ("yes", "on", "1", "true", 1)
 
 
 def should_do_markup() -> bool:
@@ -50,7 +50,7 @@ def should_do_markup() -> bool:
             py_colors = to_bool(value)
             break
 
-    # If deliverately disabled colors
+    # If deliberately disabled colors
     if os.environ.get("NO_COLOR", None):
         return False
 
@@ -68,7 +68,7 @@ def should_do_markup() -> bool:
     # Use tty detection logic as last resort because there are numerous
     # factors that can make isatty return a misleading value, including:
     # - stdin.isatty() is the only one returning true, even on a real terminal
-    # - stderr returting false if user user uses a error stream coloring solution
+    # - stderr returning false if user user uses a error stream coloring solution
     return sys.stdout.isatty()
 
 
