@@ -21,6 +21,7 @@
 
 import inspect
 import os
+
 from abc import ABCMeta, abstractmethod
 from importlib.metadata import version
 
@@ -33,14 +34,16 @@ class Driver:
     __metaclass__ = ABCMeta
     title = ""  # Short description of the driver.
 
-    def __init__(self, config=None) -> None:
+    def __init__(self, config=None) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
         """Initialize code for all :ref:`Driver` classes.
 
-        :param config: An instance of a Molecule config.
-        :returns: None
+        Args:
+            config: An instance of a Molecule config.
         """
         self._config = config
-        self._path = os.path.abspath(os.path.dirname(inspect.getfile(self.__class__)))
+        self._path = os.path.abspath(  # noqa: PTH100
+            os.path.dirname(inspect.getfile(self.__class__)),  # noqa: PTH120
+        )
         self.module = self.__module__.split(".", maxsplit=1)[0]
         self.version = version(self.module)
 
@@ -52,15 +55,15 @@ class Driver:
         :returns: str
         """
 
-    @name.setter  # type: ignore
-    def name(self, value):  # pragma: no cover
+    @name.setter
+    def name(self, value):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN202
         """Driver name setter and returns None.
 
         :returns: None
         """
 
     @property
-    def testinfra_options(self):
+    def testinfra_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Testinfra specific options and returns a dict.
 
         :returns: dict
@@ -72,16 +75,16 @@ class Driver:
 
     @property
     @abstractmethod
-    def login_cmd_template(self):  # pragma: no cover
-        """Get the login command template to be populated by ``login_options`` as \
-        a string.
+    def login_cmd_template(self):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN201
+        """Get the login command template to be populated by ``login_options`` as a string.
 
-        :returns: str
+        Returns:
+            str
         """
 
     @property
     @abstractmethod
-    def default_ssh_connection_options(self):  # pragma: no cover
+    def default_ssh_connection_options(self):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN201
         """SSH client options and returns a list.
 
         :returns: list
@@ -89,27 +92,32 @@ class Driver:
 
     @property
     @abstractmethod
-    def default_safe_files(self):  # pragma: no cover
+    def default_safe_files(self):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN201
         """Generate files to be preserved.
 
         :returns: list
         """
 
     @abstractmethod
-    def login_options(self, instance_name):  # pragma: no cover
+    def login_options(self, instance_name):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
         """Options used in the login command and returns a dict.
 
-        :param instance_name: A string containing the instance to login to.
-        :returns: dict
+        Args:
+            instance_name: A string containing the instance to login to.
+
+        Returns:
+            dict
         """
 
     @abstractmethod
-    def ansible_connection_options(self, instance_name):  # pragma: no cover
-        """Ansible specific connection options supplied to inventory and returns a \
-        dict.
+    def ansible_connection_options(self, instance_name):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
+        """Ansible specific connection options supplied to inventory and returns a dict.
 
-        :param instance_name: A string containing the instance to login to.
-        :returns: dict
+        Args:
+            instance_name: A string containing the instance to login to.
+
+        Returns:
+            dict
         """
 
     @abstractmethod
@@ -126,28 +134,28 @@ class Driver:
         """
 
     @property
-    def options(self):
+    def options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["driver"]["options"]
 
     @property
-    def instance_config(self):
-        return os.path.join(
+    def instance_config(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        return os.path.join(  # noqa: PTH118
             self._config.scenario.ephemeral_directory,
             "instance_config.yml",
         )
 
     @property
-    def ssh_connection_options(self):
+    def ssh_connection_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         if self._config.config["driver"]["ssh_connection_options"]:
             return self._config.config["driver"]["ssh_connection_options"]
         return self.default_ssh_connection_options
 
     @property
-    def safe_files(self):
+    def safe_files(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.default_safe_files + self._config.config["driver"]["safe_files"]
 
     @property
-    def delegated(self):
+    def delegated(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Is the dedriver delegated and returns a bool.
 
         :returns: bool
@@ -155,14 +163,14 @@ class Driver:
         return self.name == "default"
 
     @property
-    def managed(self):
+    def managed(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Is the driver is managed and returns a bool.
 
         :returns: bool
         """
         return self.options["managed"]
 
-    def status(self):
+    def status(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Collect the instances state and returns a list.
 
         !!! note
@@ -188,14 +196,14 @@ class Driver:
                     driver_name=driver_name,
                     provisioner_name=provisioner_name,
                     scenario_name=scenario_name,
-                    created=self._created(),
-                    converged=self._converged(),
+                    created=self._created(),  # type: ignore[no-untyped-call]
+                    converged=self._converged(),  # type: ignore[no-untyped-call]
                 ),
             )
 
         return status_list
 
-    def _get_ssh_connection_options(self):
+    def _get_ssh_connection_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
         # LogLevel=ERROR is needed in order to avoid warnings like:
         # Warning: Permanently added ... to the list of known hosts.
         return [
@@ -208,23 +216,23 @@ class Driver:
             "-o StrictHostKeyChecking=no",
         ]
 
-    def _created(self):
+    def _created(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
         return str(self._config.state.created).lower()
 
-    def _converged(self):
+    def _converged(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
         return str(self._config.state.converged).lower()
 
-    def __eq__(self, other):
+    def __eq__(self, other):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN204
         """Implement equality comparison."""
         # trick that allows us to test if a driver is loaded via:
         # if 'driver-name' in drivers()
         return str(self) == str(other)
 
-    def __lt__(self, other):
+    def __lt__(self, other):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN204
         """Implement lower than comparison."""
         return str.__lt__(str(self), str(other))
 
-    def __hash__(self):
+    def __hash__(self):  # type: ignore[no-untyped-def]  # noqa: ANN204
         """Perform object hash."""
         return self.name.__hash__()
 
@@ -236,37 +244,37 @@ class Driver:
         """Return detailed string representation of object."""
         return self.name
 
-    def __rich__(self):
+    def __rich__(self):  # type: ignore[no-untyped-def]  # noqa: ANN204
         """Return rich representation of object."""
         return self.__str__()
 
-    def get_playbook(self, step):
+    def get_playbook(self, step):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
         """Return embedded playbook location or None.
 
         The default location is relative to the file implementing the driver
         class, allowing driver writers to define playbooks without having
         to override this method.
         """
-        p = os.path.join(
+        p = os.path.join(  # noqa: PTH118
             self._path,
             "playbooks",
             step + ".yml",
         )
-        if os.path.isfile(p):
+        if os.path.isfile(p):  # noqa: PTH113
             return p
         return None
 
-    def schema_file(self):
+    def schema_file(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return None
 
-    def modules_dir(self):
+    def modules_dir(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Return path to ansible modules included with driver."""
-        p = os.path.join(self._path, "modules")
-        if os.path.isdir(p):
+        p = os.path.join(self._path, "modules")  # noqa: PTH118
+        if os.path.isdir(p):  # noqa: PTH112
             return p
         return None
 
-    def reset(self):
+    def reset(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Release all resources owned by molecule.
 
         This is a destructive operation that would affect all resources managed
