@@ -17,13 +17,18 @@
 """Interpolation Module."""
 
 import string
+
 from collections.abc import MutableMapping
 
 
-class InvalidInterpolation(Exception):
+class InvalidInterpolation(Exception):  # noqa: N818
     """InvalidInterpolation Exception."""
 
-    def __init__(self, string: str, place: Exception) -> None:
+    def __init__(
+        self,
+        string: str,  # pylint: disable=redefined-outer-name
+        place: Exception,
+    ) -> None:
         """Construct InvalidInterpolation."""
         self.string = string
         self.place = place
@@ -73,15 +78,15 @@ class Interpolator:
     def __init__(
         self,
         templater: type["TemplateWithDefaults"],
-        mapping: MutableMapping,
+        mapping: MutableMapping,  # type: ignore[type-arg]
     ) -> None:
         """Construct Interpolator."""
         self.templater = templater
         self.mapping = mapping
 
-    def interpolate(self, string: str, keep_string=None) -> str:
+    def interpolate(self, string: str, keep_string=None) -> str:  # type: ignore[no-untyped-def]  # pylint: disable=redefined-outer-name  # noqa: ANN001, D102
         try:
-            return self.templater(string).substitute(self.mapping, keep_string)  # type: ignore
+            return self.templater(string).substitute(self.mapping, keep_string)  # type: ignore[no-any-return, no-untyped-call]
         except ValueError as e:
             raise InvalidInterpolation(string, e) from e
 
@@ -91,10 +96,10 @@ class TemplateWithDefaults(string.Template):
 
     idpattern = r"[_a-z][_a-z0-9]*(?::?-[^}]+)?"
 
-    # pylint: disable=too-many-return-statements
-    def substitute(self, mapping, keep_string):
+    # pylint: disable=too-many-return-statements  # pylint: disable=useless-suppression
+    def substitute(self, mapping, keep_string):  # type: ignore[no-untyped-def]  # pylint: disable=arguments-differ  # noqa: ANN001, ANN201, D102
         # Helper function for .sub()
-        def convert(mo):
+        def convert(mo):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202, PLR0911
             # Check the most common path first.
             named = mo.group("named") or mo.group("braced")
             if named is not None:
@@ -117,7 +122,7 @@ class TemplateWithDefaults(string.Template):
             if mo.group("escaped") is not None:
                 return self.delimiter
             if mo.group("invalid") is not None:
-                self._invalid(mo)
+                self._invalid(mo)  # type: ignore[attr-defined]
                 return None
             return None
 
