@@ -22,6 +22,7 @@
 import logging
 import os
 import time
+
 from collections.abc import Callable, Iterable
 from functools import wraps
 
@@ -31,6 +32,7 @@ from enrich.logging import RichHandler
 from molecule.console import console, console_stderr
 from molecule.text import underscore
 
+
 LOG = logging.getLogger(__name__)
 
 LOG_LEVEL_LUT = {
@@ -52,17 +54,18 @@ def configure() -> None:
         show_time=False,
         show_path=False,
         markup=True,
-    )  # type: ignore
+    )
     logger.addHandler(handler)
     logger.propagate = False
     logger.setLevel(logging.INFO)
 
 
-def set_log_level(log_level: int, debug: bool) -> None:
+def set_log_level(log_level: int, debug: bool) -> None:  # noqa: FBT001
     """Set logging level.
 
-    :param log_level: verbosity control (0 - INFO, 1 - DEBUG)
-    :param debug: debug mode indicator
+    Args:
+        log_level: verbosity control (0 - INFO, 1 - DEBUG)
+        debug: debug mode indicator
     """
     # If we get verbosity level > 1, we just use debug because this is the
     # most detailed log level we have.
@@ -79,14 +82,14 @@ def get_logger(name: str) -> logging.Logger:
     return logging.getLogger("molecule." + name)
 
 
-def github_actions_groups(func: Callable) -> Callable:
+def github_actions_groups(func: Callable) -> Callable:  # type: ignore[type-arg]
     """Print group indicators before/after execution of a method."""
 
     @wraps(func)
-    def wrapper(*args, **kwargs):
+    def wrapper(*args, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN002, ANN003, ANN202
         self = args[0]
         scenario = self._config.scenario.name
-        subcommand = underscore(self.__class__.__name__)
+        subcommand = underscore(self.__class__.__name__)  # type: ignore[no-untyped-call]
         console.print(
             "::group::",
             f"[ci_info]Molecule[/] [scenario]{scenario}[/] > [action]{subcommand}[/]",
@@ -103,7 +106,7 @@ def github_actions_groups(func: Callable) -> Callable:
     return wrapper
 
 
-def gitlab_ci_sections(func: Callable) -> Callable:
+def gitlab_ci_sections(func: Callable) -> Callable:  # type: ignore[type-arg]
     """Print group indicators before/after execution of a method."""
     # GitLab requires:
     #  - \r (carriage return)
@@ -111,10 +114,10 @@ def gitlab_ci_sections(func: Callable) -> Callable:
     clear_line = "\r\033[0K"
 
     @wraps(func)
-    def wrapper(*args, **kwargs):
+    def wrapper(*args, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN002, ANN003, ANN202
         self = args[0]
         scenario = self._config.scenario.name
-        subcommand = underscore(self.__class__.__name__)
+        subcommand = underscore(self.__class__.__name__)  # type: ignore[no-untyped-call]
         console.print(
             f"section_start:{int(time.time())}:{scenario}.{subcommand}",
             end=clear_line,
@@ -144,14 +147,14 @@ def gitlab_ci_sections(func: Callable) -> Callable:
     return wrapper
 
 
-def travis_ci_folds(func: Callable) -> Callable:
+def travis_ci_folds(func: Callable) -> Callable:  # type: ignore[type-arg]
     """Print group indicators before/after execution of a method."""
 
     @wraps(func)
-    def wrapper(*args, **kwargs):
+    def wrapper(*args, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN002, ANN003, ANN202
         self = args[0]
         scenario = self._config.scenario.name
-        subcommand = underscore(self.__class__.__name__)
+        subcommand = underscore(self.__class__.__name__)  # type: ignore[no-untyped-call]
         console.print(
             f"travis_fold:start:{scenario}.{subcommand}",
             f"[ci_info]Molecule[/] [scenario]{scenario}[/] > [action]{subcommand}[/]",
@@ -173,27 +176,27 @@ def travis_ci_folds(func: Callable) -> Callable:
     return wrapper
 
 
-def section_logger(func: Callable) -> Callable:
+def section_logger(func: Callable) -> Callable:  # type: ignore[type-arg]
     """Wrap effective execution of a method."""
 
     @wraps(func)
-    def wrapper(*args, **kwargs):
+    def wrapper(*args, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN002, ANN003, ANN202
         self = args[0]
         LOG.info(
             "[info]Running [scenario]%s[/] > [action]%s[/][/]",
             self._config.scenario.name,
-            underscore(self.__class__.__name__),
+            underscore(self.__class__.__name__),  # type: ignore[no-untyped-call]
             extra={"markup": True},
         )
         rt = func(*args, **kwargs)
         # section close code goes here
-        return rt
+        return rt  # noqa: RET504
 
     return wrapper
 
 
 @cache
-def get_section_loggers() -> Iterable[Callable]:
+def get_section_loggers() -> Iterable[Callable]:  # type: ignore[type-arg]
     """Return a list of section wrappers to be added."""
     default_section_loggers = [section_logger]
     if not os.getenv("CI"):
