@@ -23,12 +23,12 @@ import logging
 
 from molecule import util
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Platforms:
-    """Platforms define the instances to be tested, and the groups to which the \
-    instances belong.
+    """Platforms define the instances to be tested, and the groups to which the instances belong.
 
     ``` yaml
 
@@ -68,26 +68,26 @@ class Platforms:
     ```
     """
 
-    def __init__(self, config, parallelize_platforms=False, platform_name=None) -> None:
+    def __init__(self, config, parallelize_platforms=False, platform_name=None) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001, FBT002
         """Initialize a new platform class and returns None.
 
-        :param config: An instance of a Molecule config.
-        :param parallelize_platforms: Parallel mode. Default is False.
-        :param platform_name: One platform to target only, defaults to None.
-        :return: None
+        Args:
+            config: An instance of a Molecule config.
+            parallelize_platforms: Parallel mode. Default is False.
+            platform_name: One platform to target only, defaults to None.
         """
         if platform_name:
-            config.config["platforms"] = util._filter_platforms(
+            config.config["platforms"] = util._filter_platforms(  # type: ignore[no-untyped-call]  # noqa: SLF001
                 config.config,
                 platform_name,
-            )  # type: ignore
+            )
         if parallelize_platforms:
-            config.config["platforms"] = util._parallelize_platforms(
+            config.config["platforms"] = util._parallelize_platforms(  # type: ignore[no-untyped-call]  # noqa: SLF001
                 config.config,
-                config._run_uuid,
-            )  # type: ignore
+                config._run_uuid,  # noqa: SLF001
+            )
         self._config = config
 
     @property
-    def instances(self):
+    def instances(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["platforms"]
