@@ -26,26 +26,26 @@ import warnings
 from molecule import util
 from molecule.api import MoleculeRuntimeWarning
 
+
 LOG = logging.getLogger(__name__)
 
 
 class AnsiblePlaybook:
     """Provisioner Playbook."""
 
-    def __init__(self, playbook, config, verify=False) -> None:
-        """Set up the requirements to execute ``ansible-playbook`` and returns \
-        None.
+    def __init__(self, playbook, config, verify=False) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001, FBT002
+        """Set up the requirements to execute ``ansible-playbook`` and returns None.
 
-        :param playbook: A string containing the path to the playbook.
-        :param config: An instance of a Molecule config.
-        :param verify: An optional bool to toggle the Plabook mode between
-         provision and verify. False: provision; True: verify. Default is False.
-        :returns: None
+        Args:
+            playbook: A string containing the path to the playbook.
+            config: An instance of a Molecule config.
+            verify: An optional bool to toggle the Playbook mode between provision and verify.
+                False provision; True: verify. Default is False.
         """
         self._ansible_command = None
         self._playbook = playbook
         self._config = config
-        self._cli = {}  # type: ignore
+        self._cli = {}  # type: ignore[var-annotated]
         if verify:
             self._env = util.merge_dicts(
                 self._config.verifier.env,
@@ -54,21 +54,17 @@ class AnsiblePlaybook:
         else:
             self._env = self._config.provisioner.env
 
-    def bake(self):
-        """Bake an ``ansible-playbook`` command so it's ready to execute and \
-        returns ``None``.
-
-        :return: None
-        """
+    def bake(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Bake an ``ansible-playbook`` command so it's ready to execute and returns ``None``."""
         if not self._playbook:
             return
 
         # Pass a directory as inventory to let Ansible merge the multiple
         # inventory sources located under
-        self.add_cli_arg("inventory", self._config.provisioner.inventory_directory)
+        self.add_cli_arg("inventory", self._config.provisioner.inventory_directory)  # type: ignore[no-untyped-call]
         options = util.merge_dicts(self._config.provisioner.options, self._cli)
-        verbose_flag = util.verbose_flag(options)
-        if self._playbook != self._config.provisioner.playbooks.converge:
+        verbose_flag = util.verbose_flag(options)  # type: ignore[no-untyped-call]
+        if self._playbook != self._config.provisioner.playbooks.converge:  # noqa: SIM102
             if options.get("become"):
                 del options["become"]
 
@@ -87,21 +83,22 @@ class AnsiblePlaybook:
         else:
             ansible_args = []
 
-        self._ansible_command = [
+        self._ansible_command = [  # type: ignore[assignment]
             "ansible-playbook",
-            *util.dict2args(options),
+            *util.dict2args(options),  # type: ignore[arg-type]
             *util.bool2args(verbose_flag),
             *ansible_args,
             self._playbook,  # must always go last
         ]
 
-    def execute(self, action_args=None):
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
         """Execute ``ansible-playbook`` and returns a string.
 
-        :return: str
+        Returns:
+            str
         """
         if self._ansible_command is None:
-            self.bake()
+            self.bake()  # type: ignore[no-untyped-call]
 
         if not self._playbook:
             LOG.warning("Skipping, %s action has no playbook.", self._config.action)
@@ -112,7 +109,7 @@ class AnsiblePlaybook:
             self._config.driver.sanity_checks()
             cwd = self._config.scenario_path
             result = util.run_command(
-                cmd=self._ansible_command,
+                cmd=self._ansible_command,  # type: ignore[arg-type]
                 env=self._env,
                 debug=self._config.debug,
                 cwd=cwd,
@@ -122,29 +119,28 @@ class AnsiblePlaybook:
             from rich.markup import escape
 
             util.sysexit_with_message(
-                f"Ansible return code was {result.returncode}, command was: [dim]{escape(shlex.join(result.args))}[/dim]",
+                f"Ansible return code was {result.returncode}, command was: [dim]{escape(shlex.join(result.args))}[/dim]",  # noqa: E501
                 result.returncode,
                 warns=warns,
             )
 
         return result.stdout
 
-    def add_cli_arg(self, name, value):
+    def add_cli_arg(self, name, value):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
         """Add argument to CLI passed to ansible-playbook and returns None.
 
-        :param name: A string containing the name of argument to be added.
-        :param value: The value of argument to be added.
-        :return: None
+        Args:
+            name: A string containing the name of argument to be added.
+            value: The value of argument to be added.
         """
         if value:
             self._cli[name] = value
 
-    def add_env_arg(self, name, value):
-        """Add argument to environment passed to ansible-playbook and returns \
-        None.
+    def add_env_arg(self, name, value):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
+        """Add argument to environment passed to ansible-playbook and returns None.
 
-        :param name: A string containing the name of argument to be added.
-        :param value: The value of argument to be added.
-        :return: None
+        Args:
+            name: A string containing the name of argument to be added.
+            value: The value of argument to be added.
         """
         self._env[name] = value
