@@ -22,43 +22,45 @@ import logging
 
 from molecule import util
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Scenarios:
     """The Scenarios groups one or more scenario objects Molecule will execute."""
 
-    def __init__(self, configs, scenario_name=None) -> None:
+    def __init__(self, configs, scenario_name=None) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
         """Initialize a new scenarios class and returns None.
 
-        :param configs: A list containing Molecule config instances.
-        :param scenario_name: A string containing the name of the scenario.
-        :return: None
+        Args:
+            configs: A list containing Molecule config instances.
+            scenario_name: A string containing the name of the scenario.
         """
         self._configs = configs
         self._scenario_name = scenario_name
         self._scenarios = self.all
 
-    def next(self):
+    def next(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         if not self._scenarios:
             raise StopIteration
         return self._scenarios.pop(0)
 
-    def __iter__(self):
+    def __iter__(self):  # type: ignore[no-untyped-def]  # noqa: ANN204
         """Make object iterable."""
         return self
 
     __next__ = next  # Python 3.X compatibility
 
     @property
-    def all(self):
+    def all(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Return a list containing all scenario objects.
 
-        :return: list
+        Returns:
+            list
         """
         if self._scenario_name:
-            scenarios = self._filter_for_scenario()
-            self._verify()
+            scenarios = self._filter_for_scenario()  # type: ignore[no-untyped-call]
+            self._verify()  # type: ignore[no-untyped-call]
 
             return scenarios
 
@@ -66,7 +68,7 @@ class Scenarios:
         scenarios.sort(key=lambda x: x.directory)
         return scenarios
 
-    def print_matrix(self):
+    def print_matrix(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         msg = "Test matrix"
         LOG.info(msg)
 
@@ -75,35 +77,31 @@ class Scenarios:
             tree[scenario.name] = list(scenario.sequence)
         util.print_as_yaml(tree)
 
-    def sequence(self, scenario_name: str) -> list[str]:
+    def sequence(self, scenario_name: str) -> list[str]:  # noqa: D102
         for scenario in self.all:
             if scenario.name == scenario_name:
                 return list(scenario.sequence)
-        raise RuntimeError(f"Unable to find sequence for {scenario_name} scenario.")
+        raise RuntimeError(  # noqa: TRY003
+            f"Unable to find sequence for {scenario_name} scenario.",  # noqa: EM102
+        )
 
-    def _verify(self):
-        """Verify the specified scenario was found and returns None.
-
-        :return: None
-        """
+    def _verify(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Verify the specified scenario was found and returns None."""
         scenario_names = [c.scenario.name for c in self._configs]
         if self._scenario_name not in scenario_names:
             msg = f"Scenario '{self._scenario_name}' not found.  Exiting."
             util.sysexit_with_message(msg)
 
-    def _filter_for_scenario(self):
-        """Find the scenario matching the provided scenario name and returns a \
-        list.
+    def _filter_for_scenario(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Find the scenario matching the provided scenario name and returns a list.
 
-        :return: list
+        Returns:
+            list
         """
-        return [
-            c.scenario for c in self._configs if c.scenario.name == self._scenario_name
-        ]
+        return [c.scenario for c in self._configs if c.scenario.name == self._scenario_name]
 
-    def _get_matrix(self):
-        """Build a matrix of scenarios with sequence to include and returns a \
-        dict.
+    def _get_matrix(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Build a matrix of scenarios with sequence to include and returns a dict.
 
         {
             scenario_1: {
@@ -119,7 +117,8 @@ class Scenarios:
             },
         }
 
-        :returns: dict
+        Returns:
+            dict
         """
         return {
             scenario.name: {
