@@ -24,7 +24,8 @@ import logging
 import os
 
 from molecule import util
-from molecule.api import Verifier
+from molecule.api import Verifier  # type: ignore[attr-defined]
+
 
 LOG = logging.getLogger(__name__)
 
@@ -87,22 +88,22 @@ class Testinfra(Verifier):
     .. _`Testinfra`: https://testinfra.readthedocs.io
     """
 
-    def __init__(self, config=None) -> None:
+    def __init__(self, config=None) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
         """Set up the requirements to execute ``testinfra`` and returns None.
 
-        :param config: An instance of a Molecule config.
-        :return: None
+        Args:
+            config: An instance of a Molecule config.
         """
         super().__init__(config)
         self._testinfra_command = None
-        self._tests = []  # type: ignore
+        self._tests = []  # type: ignore[var-annotated]
 
     @property
-    def name(self):
+    def name(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return "testinfra"
 
     @property
-    def default_options(self):
+    def default_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         d = self._config.driver.testinfra_options
         d["p"] = "no:cacheprovider"
         if self._config.debug:
@@ -116,58 +117,56 @@ class Testinfra(Verifier):
     # NOTE(retr0h): Override the base classes' options() to handle
     # ``ansible-galaxy`` one-off.
     @property
-    def options(self):
+    def options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         o = self._config.config["verifier"]["options"]
         # NOTE(retr0h): Remove verbose options added by the user while in
         # debug.
         if self._config.debug:
-            o = util.filter_verbose_permutation(o)
+            o = util.filter_verbose_permutation(o)  # type: ignore[no-untyped-call]
 
         return util.merge_dicts(self.default_options, o)
 
     @property
-    def default_env(self):
+    def default_env(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         env = util.merge_dicts(os.environ, self._config.env)
         env = util.merge_dicts(env, self._config.provisioner.env)
 
-        return env
+        return env  # noqa: RET504
 
     @property
-    def additional_files_or_dirs(self):
+    def additional_files_or_dirs(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         files_list = []
         c = self._config.config
         for f in c["verifier"]["additional_files_or_dirs"]:
-            glob_path = os.path.join(self._config.verifier.directory, f)
-            glob_list = glob.glob(glob_path)
+            escaped = glob.escape(self._config.verifier.directory)
+            glob_path = os.path.join(escaped, f)  # noqa: PTH118
+            glob_list = glob.glob(glob_path)  # noqa: PTH207
             if glob_list:
                 files_list.extend(glob_list)
 
         return files_list
 
-    def bake(self):
-        """Bake a ``testinfra`` command so it's ready to execute and returns None.
-
-        :return: None
-        """
+    def bake(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Bake a ``testinfra`` command so it's ready to execute and returns None."""
         options = self.options
-        verbose_flag = util.verbose_flag(options)
+        verbose_flag = util.verbose_flag(options)  # type: ignore[no-untyped-call]
         args = verbose_flag
 
-        self._testinfra_command = [
+        self._testinfra_command = [  # type: ignore[assignment]
             "pytest",
             *util.dict2args(options),
             *self._tests,
             *args,
         ]
 
-    def execute(self, action_args=None):
+    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, D102
         if not self.enabled:
             msg = "Skipping, verifier is disabled."
             LOG.warning(msg)
             return
 
         if self._config:
-            self._tests = self._get_tests(action_args)
+            self._tests = self._get_tests(action_args)  # type: ignore[no-untyped-call]
         else:
             self._tests = []
         if not len(self._tests) > 0:
@@ -175,13 +174,13 @@ class Testinfra(Verifier):
             LOG.warning(msg)
             return
 
-        self.bake()
+        self.bake()  # type: ignore[no-untyped-call]
 
         msg = f"Executing Testinfra tests found in {self.directory}/..."
         LOG.info(msg)
 
         result = util.run_command(
-            self._testinfra_command,
+            self._testinfra_command,  # type: ignore[arg-type]
             env=self.env,
             debug=self._config.debug,
             cwd=self._config.scenario.directory,
@@ -192,17 +191,18 @@ class Testinfra(Verifier):
         else:
             util.sysexit(result.returncode)
 
-    def _get_tests(self, action_args=None):
+    def _get_tests(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
         """Walk the verifier's directory for tests and returns a list.
 
-        :return: list
+        Returns:
+            list
         """
         if action_args:
             tests = []
             for arg in action_args:
                 args_tests = list(
-                    util.os_walk(
-                        os.path.join(self._config.scenario.directory, arg),
+                    util.os_walk(  # type: ignore[no-untyped-call]
+                        os.path.join(self._config.scenario.directory, arg),  # noqa: PTH118
                         "test_*.py",
                         followlinks=True,
                     ),
@@ -211,7 +211,7 @@ class Testinfra(Verifier):
             return sorted(tests)
         return sorted(
             list(
-                util.os_walk(
+                util.os_walk(  # type: ignore[no-untyped-call]
                     self.directory,
                     "test_*.py",
                     followlinks=True,
@@ -220,7 +220,7 @@ class Testinfra(Verifier):
             + self.additional_files_or_dirs,
         )
 
-    def schema(self):
+    def schema(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return {
             "verifier": {
                 "type": "dict",
